@@ -10,7 +10,7 @@ from .exc import ParseError
 from .namespaces import XML_NS
 from .tokenize import Token
 
-match_double_hyphen = re.compile(r'--(?!>)')
+match_double_hyphen = re.compile(r'--(?!(-)*>)')
 match_tag_prefix_and_name = re.compile(
     r'^(?P<prefix></?)(?P<name>([^:\n\r ]+:)?[^ \n\t\r>/]+)'
     r'(?P<suffix>(?P<space>\s*)/?>)?',
